/*
  The BREP Library.
  Copyright (C) 1996 Philippe Bekaert

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/* vertex_octree.h: Boundary Representation vertices organised in an
 *		    octree. For fast vertex lookup. */

#ifndef _BREP_VERTEX_OCTREE_H_
#define _BREP_VERTEX_OCTREE_H_

#include "brep.h"
#include "pools.h"
#include "Octree.h"

/* struct BREP_VERTEX_OCTREE is defined in brep.h and has same layout as
 * struct OCTREE in Octree.h */

#define BrepVertexOctreeCreate()	((BREP_VERTEX_OCTREE *)OctreeCreate())

#define BrepVertexOctreeAdd(poctree, pbrep_vertex)     \
        (BREP_VERTEX_OCTREE *)OctreeAddWithDuplicates((OCTREE *)poctree, (void *)pbrep_vertex, (int (*)(void *, void *))BrepVertexCompare)

#define BrepVertexOctreeFind(poctree, pbrep_vertex)     \
        (BREP_VERTEX *)OctreeFind((OCTREE *)poctree, (void *)pbrep_vertex, (int (*)(void *, void *))BrepVertexCompare)

#define BrepVertexOctreeDestroy(poctree) \
        OctreeDestroy((OCTREE *)poctree)

#define BrepVertexOctreeIterate(poctree, func) \
        OctreeIterate((OCTREE *)poctree, (void (*)(void *))func)

/* compares two vertices. Calls a user installed routine to compare the
 * client data of two vertices. The routine to be used is specified with
 * BrepSetVertexCompareRoutine() in brep.h */
extern int BrepVertexCompare(BREP_VERTEX *v1, BREP_VERTEX *v2);

#endif /* _BREP_VERTEX_OCTREE_H_ */
