/* brepit.c: iterators not in the BREP library --- not robust ... */
/*
  The BREP Library.
  Copyright (C) 1996 Philippe Bekaert

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "brepit.h"
#include "pools.h"

/* combined iterators not in the brep library */
void BrepSolidIterateFaces(BREP_SOLID *solid, void (*func)(BREP_FACE *))
{
  BREP_SHELL *shell;
  BREP_FACE *face;

  for (shell = solid->shells; shell; shell = (shell->next == solid->shells ? (BREP_SHELL *)NULL : shell->next)) {
    for (face = shell->faces; face; face = (face->next == shell->faces ? (BREP_FACE *)NULL : face->next)) {
      func(face);
    }
  }
}

void BrepSolidIterateFaces1A(BREP_SOLID *solid, void (*func)(BREP_FACE *, void *), void *parm)
{
  BREP_SHELL *shell;
  BREP_FACE *face;

  for (shell = solid->shells; shell; shell = (shell->next == solid->shells ? (BREP_SHELL *)NULL : shell->next)) {
    for (face = shell->faces; face; face = (face->next == shell->faces ? (BREP_FACE *)NULL : face->next)) {
      func(face, parm);
    }
  }
}

void BrepSolidIterateContours(BREP_SOLID *solid, void (*func)(BREP_CONTOUR *))
{
  BREP_SHELL *shell;
  BREP_FACE *face;
  BREP_CONTOUR *contour;

  for (shell = solid->shells; shell; shell = (shell->next == solid->shells ? (BREP_SHELL *)NULL : shell->next)) {
    for (face = shell->faces; face; face = (face->next == shell->faces ? (BREP_FACE *)NULL : face->next)) {
      for (contour = face->outer_contour; contour; contour = (contour->next == face->outer_contour ? (BREP_CONTOUR *)NULL : contour->next)) {
	func(contour);
      }
    }
  }
}

void BrepSolidIterateContours1A(BREP_SOLID *solid, void (*func)(BREP_CONTOUR *, void *), void *parm)
{
  BREP_SHELL *shell;
  BREP_FACE *face;
  BREP_CONTOUR *contour;

  for (shell = solid->shells; shell; shell = (shell->next == solid->shells ? (BREP_SHELL *)NULL : shell->next)) {
    for (face = shell->faces; face; face = (face->next == shell->faces ? (BREP_FACE *)NULL : face->next)) {
      for (contour = face->outer_contour; contour; contour = (contour->next == face->outer_contour ? (BREP_CONTOUR *)NULL : contour->next)) {
	func(contour, parm);
      }
    }
  }
}

void BrepContourReverseIterateVertices(BREP_CONTOUR *contour, void (*func)(BREP_VERTEX *))
{
  BREP_WING *wing;

  if (contour->wings) {
    wing = contour->wings->prev;
    do {
      func(wing->vertex);
      wing = wing->prev;
    } while (wing != contour->wings->prev);
  }
}


