/* color.h */
/*
  The BREP Library.
  Copyright (C) 1996 Philippe Bekaert

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef _COLOR_H_
#define _COLOR_H_

/* colors in RGB, the colormodel used by the rendering subsystem, here assumed
 * to be a display screen. The display hardware wants RGB triplets:
 * 3 floats between 0. and 1., determining how intense the red, green
 * and blue phosphor on the screen will shine. */
typedef struct RGB {
	float r, g, b;
} RGB;

/* some RGB colors for e.g. debugging purposes */
extern RGB Black, White, Green, Yellow, Red, Magenta, Blue, Turquoise;

/* macro to print an RGB triplet */
#define RGBPrint(fp, color) 	fprintf(fp, "%g %g %g", (color).r, (color).g, (color).b);

/* macro to fill in an RGB structure with given red,green and blue components */
#define RGBSET(color, R, G, B)  ((color).r = (R), (color).g = (G), (color).b = (B))

#define RGBSCALE(s, col, scol) {(scol).r = (s) * (col).r; (scol).g = (s) * (col).g; (scol).b = (s) * (col).b;}

/* clips RGB intensities to the interval [0,1] */
#define RGBCLIP(color)		(\
			(color).r = ((color).r < 0. ? 0. : ((color).r > 1. ? 1. : (color).r)), \
			(color).g = ((color).g < 0. ? 0. : ((color).g > 1. ? 1. : (color).g)), \
			(color).b = ((color).b < 0. ? 0. : ((color).b > 1. ? 1. : (color).b)))

/* gamma correction */
#define RGBGAMMACORRECT(color, gamma)  (\
			(color).r = (gamma==1. ? (color).r : pow((color).r, 1./gamma)), \
			(color).g = (gamma==1. ? (color).g : pow((color).g, 1./gamma)), \
			(color).b = (gamma==1. ? (color).b : pow((color).b, 1./gamma)))

#endif /*_COLOR_H_*/



