/* error.c: afdrukken van waarschuwingen, fouten, fatale fouten  */
/*
  The BREP Library.
  Copyright (C) 1996 Philippe Bekaert

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <stdlib.h>
#include <stdio.h>
#include <stdarg.h>
#include "error.h"

static int errorOccurred = FALSE;

/* geeft FALSE terug indien sinds de vorige oproep zich geen fouten hebben
 * voorgedaan. */
int ErrorOccurred(void)
{
	int errocc = errorOccurred;

	errorOccurred = FALSE;
	return errocc;
}

/* drukt een foutenboodschap af */
void Error(char *routine, char *text, ...)
{
	va_list pvar;

	fprintf(stderr, "Error");
	if (routine) fprintf(stderr, " (in subroutine %s)", routine);
	fprintf(stderr, ": ");

	va_start(pvar, text);
	vfprintf(stderr, text, pvar);
	va_end(pvar);

	fprintf(stderr, ".\n");
	fflush(stderr);

	errorOccurred = TRUE;
}

/* een fatale fout: druk boodschap of en verlaat het programma
 * met de opgegeven foutencode */ 
void Fatal(int errcode, char *routine, char *text, ...)
{
	va_list pvar;

	fprintf(stderr, "Fatal error");
	if (routine) fprintf(stderr, " (in subroutine %s)", routine);
	fprintf(stderr, ": ");

	va_start(pvar, text);
	vfprintf(stderr, text, pvar);
	va_end(pvar);

	fprintf(stderr, ".\n");
	fflush(stderr);
	/*	exit(errcode); */
	abort();

	errorOccurred = TRUE;
}

void Warning(char *routine, char *text, ...)
{
	va_list pvar;

	fprintf(stderr, "Warning");
	if (routine) fprintf(stderr, " (in subroutine %s)", routine);
	fprintf(stderr, ": ");

	va_start(pvar, text);
	vfprintf(stderr, text, pvar);
	va_end(pvar);

	fprintf(stderr, ".\n"); 
	fflush(stderr);
}
