/* error.h: afdrukken van waarschuwingen, fouten, fatale fouten  */
/*
  The BREP Library.
  Copyright (C) 1996 Philippe Bekaert

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef _ERROR_H_
#define _ERROR_H_


#ifndef NULL
#define NULL (char *)0
#endif /*NULL*/

#ifndef FALSE
#define FALSE 0
#endif /*FALSE*/

#ifndef TRUE
#define TRUE 1
#endif /*TRUE*/

/* drukt een foutenboodschap af.
 * argumenten: naam van de routine waar de fout gebeurde, of NULL indien niet
 * relevant en de rest zoals printf */
extern void Error(char *routine, char *text, ...);

/* drukt een waarschuwing af */
extern void Warning(char *routine, char *text, ...);

/* 
 * Drukt een fatale foutenboodschap af en beeindigt het programma. 
 * eerste argument is een foutencode waarmee het programma verlaten moet 
 * worden. Conventie: errcode < 0 ===> fout in het programma.
 * 
 * Foutencodes:
 *	-1: een onmogelijke situatie doet zich voor 
 *	-2: een datastructuur lijkt om zeep 
 *
 *       1: fouten bij het (re)alloceren van geheugen
 */
extern void Fatal(int errcode, char *routine, char *text, ...);

/* geeft FALSE terug indien er geen fouten gebeurd zijn sinds de laatste
 * oproep naar deze funtie en TRUE anders. */
extern int ErrorOccurred(void);

#endif /*_ERROR_H_*/
