/* raytrace.h */
/*
  The BREP Library.
  Copyright (C) 1996 Philippe Bekaert

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef _RAYTRACE_H_
#define _RAYTRACE_H_

#include "ray.h"
#include "geometry.h"
#include "brep.h"

extern BREP_FACE *FaceIntersect(BREP_FACE *face, RAY *ray, float mindist, float *maxdist);
extern BREP_FACE *ShellIntersect(BREP_SHELL *shell, RAY *ray, float mindist, float *maxdist,
				int shadowtest);
extern BREP_FACE *SolidIntersect(BREP_SOLID *solid, RAY *ray, float mindist, float *maxdist,
				 int shadowtest);

#define CULL_NONE 	0
#define CULL_FRONT	1
#define CULL_BACK	2
extern unsigned RaytraceCull(unsigned flags);

extern int ContourWinding(BREP_CONTOUR *contour, DVEC2D *center, int index);

/* the following are in vertinsol.c instead of here */

/* simple application of raytracing: testing whether a vertex is inside 
 * the solid. This routine returns OUTMASK if the vertex is outside,
 * INMASK if inside, and 0 if it can not be determined (serious error). */
extern int ContourInSolid(BREP_CONTOUR *contour, BREP_SOLID *solod);

extern int VertexInSolid(VERTEX *vertex_data, BREP_SOLID *solod);
extern int VertexInsideContour(VERTEX *vertex_data, BREP_CONTOUR *contour);

#endif /*_RAYTRACE_H_*/
