/* readmgf.h */
/*
  The BREP Library.
  Copyright (C) 1996 Philippe Bekaert

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef _READMGF_H_
#define _READMGF_H_

/* sets the number of quarter circle divisions for discretizing cylinders,
 * sphere, cones ... */
extern void MGFSetNrQuartCircDivs(int divs);

/* sets a default accuracy for the coordinates of a vertex */
extern void MGFSetVertexTolerance(float tolerance);

/* sets a flag indicating whether all surfaces should be considered
 * 1-sided (the best for "good" models) or not. */
extern void MGFSetIgnoreSidedness(int yesno);

/* Specify whether the vertex order in an MGF file to be read is to be
 * respected or not. When specifying that the vertex order is not relevant,
 * a test is performed to see what order yields to the least number of conflicts.
 * There is a conflict if a wing to be created already exists. This is e.g.
 * the case when vertex order is not consistent in the input file. Specifying
 * FALSE (don't respect vertex order) may lead to a consistent vertex ordering
 * in each shell. */
extern void MGFRespectVertexOrder(int truefalse);

extern void ReadMGF(char *filename);
extern char *current_directory;

#endif /*_READMGF_H_*/
