/* vectortype.h: vector type definitions */
/*
  The BREP Library.
  Copyright (C) 1996 Philippe Bekaert

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef _VECTORTYPE_H_
#define _VECTORTYPE_H_

/* a vector in 3D space */
typedef struct VECTOR {
	float x, y, z;
} VECTOR;

/* a vector in 2D space */
typedef struct VEC2D {
	float 	u, v;
} VEC2D;

/* double floating point vectors: The extra precision is sometimes needed eg
 * for sampling a spherical triangle or computing an analytical point to
 * patch factor, also for accurately computing normals and areas ... */
typedef struct DVECTOR {
	double x, y, z;
} DVECTOR;

typedef struct DVEC2D {
	double 	u, v;
} DVEC2D;

#define POINT VECTOR
#define POINT2D VEC2D
#define DPOINT DVECTOR
#define DPOINT2D DVEC2D

/* memory management routines, to store vectors in linear lists or other generic
 * data structures of the GDT library */

/* creates a vector with given components */
extern VECTOR *VectorCreate(float x, float y, float z);

/* destroys a vector */
extern void VectorDestroy(VECTOR *vector);

/* duplicates a vector */
extern VECTOR *VectorCopy(VECTOR *vector);

/* compute the distance between two 3D points */
extern double VectorDist(DVECTOR *p1, DVECTOR *p2);

/* The routines below were copied from the rayshade source files. */

/* normalizes the vector and returns the norm. Other difference with 
 * VECTORNORMALIZE is that it is explicitely tested that the components of the 
 * vector are within [-1,1] */
extern double VectorNormalize(VECTOR *vector);

/*
 * Find the "dominant" part of the vector (eg patch-normal).  This
 * is used to turn the point-in-polygon test into a 2D problem.
 */
extern int VectorDominantCoord(VECTOR *v);

#endif /*_VECTORTYPE_H_*/
